@@ -383,7 +383,7 @@ class WordType(models.Model):
         return fwnd
 
     def getPhonoProb(self):
-        if self.PhonoProb is None:
+        if self.SPhonoProb is None:
             self.setViteLuceProb()
 
         return self.SPhonoProb,self.BiPhonoProb
